searchData={"items":[{"type":"module","title":"Turboprop","doc":"","ref":"Turboprop.html"},{"type":"module","title":"Tools - Turboprop","doc":"Turboprop consists of multiple tools, each with their own purpose in building your component library.","ref":"Turboprop.html#module-tools"},{"type":"module","title":"Turboprop Hooks - Turboprop","doc":"Turboprop Hooks allow adding a ton of accessibility features to your components by simply adding a hook and a few data attributes to them.  \nThis includes:\n\n- Keyboard interactions\n- Focus management\n- ARIA attributes\n\nYou can either install and use them through the hex.pm dependency and some helpers we offer to add the relevant attributes to a component,\nor install them directly through npm and adding the attributes yourself.  \n\nAs an example, this renders a fully accessible dropdown menu:\n\n```heex\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       Anchor \n     \n   \n \n```","ref":"Turboprop.html#module-turboprop-hooks"},{"type":"module","title":"Turboprop Merge - Turboprop","doc":"Turboprop Merge allows you to easily merge a list of Tailwind Classes to avoid style conflicts.\n\nImagine this component:\n\n```elixir\nattr :class, :string, doc: \"Class override\"\ndef button(assigns) do\n  ~H\"\"\"\n   Click me! \n  \"\"\"\nend\n```\n\nAnd imagine wanting to make the text a little bigger as a one-off. You've already added a `@class` attribute, but rendering the component\nwith `class=\"text-lg\"` will lead to an HTML output of `\"bg-black px-3 py-1.5 text-sm text-lg\"`, with two competing font size classes.\n\nNow, replace the `class` attribute with `class={merge([\"bg-black px-3 py-1.5 text-sm\", @class])}` and you will magically get\n`\"bg-black px-3 py-1.5 text-lg\"`.","ref":"Turboprop.html#module-turboprop-merge"},{"type":"module","title":"Turboprop.Hooks","doc":"Turboprop Hooks offer an easy way to build accessible components.  \n\nYou can easily add features like keyboard interaction, focus management and ARIA attributes to your component.  \nTurboprop Hooks are built around the state machines of [Zag](https://zagjs.com) and offer the same rules as them. You will find a link to\neach state machine's documentation in the hook's module.","ref":"Turboprop.Hooks.html"},{"type":"module","title":"Installation - Turboprop.Hooks","doc":"","ref":"Turboprop.Hooks.html#module-installation"},{"type":"module","title":"With mix - Turboprop.Hooks","doc":"If you use the esbuild setup Phoenix ships with by default, the hooks will automatically be available to your assets after adding\nTurboprop to your `mix.exs`. You then only need to add the hooks to your LiveView configuration.","ref":"Turboprop.Hooks.html#module-with-mix"},{"type":"module","title":"With npm - Turboprop.Hooks","doc":"The hooks are also available packaged as an npm package, [`@leuchtturm/turboprop`](https://npmjs.com/package/@leuchtturm/turboprop). Add \nit to your assets by running `npm i --save-exact @leuchtturm/turboprop` or the equivalent for the package manager you are using.","ref":"Turboprop.Hooks.html#module-with-npm"},{"type":"module","title":"Loading the hooks - Turboprop.Hooks","doc":"To reduce bundle size, it's recommended to only add the hooks actually used. For example, if only the `PinInput` hook is used:\n\n```javascript\nimport { PinInput } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    PinInput\n  },\n});\n```\n\nFor convenience, Turboprop also allows importing and adding all hooks at once:\n\n```javascript\nimport { Hooks } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    ...Hooks\n  },\n});\n```\n\nThat's it!","ref":"Turboprop.Hooks.html#module-loading-the-hooks"},{"type":"module","title":"Anatomy - Turboprop.Hooks","doc":"Each hook comes with a wrapper that adds the `phx-hook` directive and a bunch of `data` attributes that specify which role each element\nhas. Revisiting the dropdown menu example from the [Turboprop](`m:Turboprop`) documentation, the expanded elements look like this:\n\n```html\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       \n        Anchor\n       \n     \n   \n \n```\nFor the `Menu` hook, the required parts are `trigger`, `positioner`, `content`, and `item`. In addition to that, it can also be configured\nwith optional parts like `separator` and `group`. Each hook's module will list both required and optional fields and how they relate to\neach other with nesting.  \nMost hooks only need the `data-part` attributes set, but some also have callbacks to the server where an event is required. Check the\ndocumentation for each hook.","ref":"Turboprop.Hooks.html#module-anatomy"},{"type":"function","title":"Turboprop.Hooks.id/0","doc":"","ref":"Turboprop.Hooks.html#id/0"},{"type":"module","title":"Turboprop.Hooks.Menu","doc":"Provides a robust, accessible dropdown and context menu system. This module serves as a wrapper around\n[Zag's Menu state machine](https://github.com/chakra-ui/zag/tree/main/packages/machines/menu), designed for displaying a list of actions \nor options to the user within a web application.","ref":"Turboprop.Hooks.Menu.html"},{"type":"module","title":"Required Components: - Turboprop.Hooks.Menu","doc":"- `menu`: The main container for the menu.\n- `menu_trigger`: Activates the dropdown or context menu.\n- `menu_positioner`: Controls the menu's position in the viewport.\n- `menu_content`: Contains the clickable menu items.\n- `menu_item`: Represents an individual action or option within the menu.","ref":"Turboprop.Hooks.Menu.html#module-required-components"},{"type":"module","title":"Optional Components: - Turboprop.Hooks.Menu","doc":"- `menu_item_group`: Groups related items within the menu.\n- `menu_item_group_label`: Provides a label for item groups, enhancing accessibility.\n- `menu_separator`: Visually separates items or groups within the menu.","ref":"Turboprop.Hooks.Menu.html#module-optional-components"},{"type":"module","title":"Example - Turboprop.Hooks.Menu","doc":"```heex\n \n   \n    Menu\n   \n   \n     \n      <.link navigate=\"/dashboard\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n        Dashboard\n      </.link>\n       \n       Account \n       \n        <.link navigate=\"/signup\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Sign up\n        </.link>\n        <.link navigate=\"/login\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Login\n        </.link>\n       \n     \n   \n \n```","ref":"Turboprop.Hooks.Menu.html#module-example"},{"type":"function","title":"Turboprop.Hooks.Menu.menu/0","doc":"Wrapper element for menus.","ref":"Turboprop.Hooks.Menu.html#menu/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_content/0","doc":"Wrapper around menu items.\n\nNeeds to be positioned as direct child of `menu_positioner/0`.","ref":"Turboprop.Hooks.Menu.html#menu_content/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item/0","doc":"Menu item.","ref":"Turboprop.Hooks.Menu.html#menu_item/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-required-attributes"},{"type":"function","title":"Styling - Turboprop.Hooks.Menu.menu_item/0","doc":"When a menu item is highlighted, it will receive a `data-highlighted` attribute which can be used to style the item. If using Tailwind,\nthis can be achieved by adding `data-[highlighted]:bg-gray-100` to the class list.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-styling"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group/0","doc":"Element to group multiple menu items together.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group/0","doc":"- `id` - Will be auto-generated if not set.\n- `name` - If adding a label through `menu_item_group_label/0`, the group needs to have a name set.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"Label for a menu group.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"- `data-for` - The `menu_item_group/0`'s `name`.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_positioner/0","doc":"Element to position a menu in the viewport.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_positioner/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_separator/0","doc":"Element to separate menu items.\n\nNeeds to be positioned as direct child of either `menu_content/0` or `menu_item_group/0`.","ref":"Turboprop.Hooks.Menu.html#menu_separator/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_trigger/0","doc":"Button to open a menu.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_trigger/0"},{"type":"module","title":"Turboprop.Hooks.PinInput","doc":"Input for PINs and OTPs.\n\nConsists of multiple inputs, each allowing one character at a time. When the digit or letter is entered, focus transfers to the next \ninput in the sequence, until every input is filled.","ref":"Turboprop.Hooks.PinInput.html"},{"type":"module","title":"Required elements - Turboprop.Hooks.PinInput","doc":"- `pin_input`: Wrapper element that initialises the hook and sets configuration.\n- `pin_input_root`: Wrapper around the actual input fields.\n- `pin_input_input`: Input elements, one for each character.","ref":"Turboprop.Hooks.PinInput.html#module-required-elements"},{"type":"module","title":"Optional elements - Turboprop.Hooks.PinInput","doc":"- `pin_input_label`: Label for the input.","ref":"Turboprop.Hooks.PinInput.html#module-optional-elements"},{"type":"module","title":"Options - Turboprop.Hooks.PinInput","doc":"Options are set on the outer wrapper element through data attributes.  \nFor boolean attributes, adding the attribute with either an empty value or `\"true\"` is considered truthy, every other value falsy.\n\n- `data-type`: The type of the input. Defines which characters are allowed. Has to be one of `alphanumeric`, `numeric` or `alphabetic`.\n- `data-otp`: Add when the input is a One-Time Password to correctly set the `autocomplete` tag.\n- `data-blur-on-complete`: Blur the last input when the user completes the pin input.\n- `data-placeholder`: The placeholder to show in each input field.\n- `data-dir`: Set to `rtl` if the pin should be entered right-to-left.","ref":"Turboprop.Hooks.PinInput.html#module-options"},{"type":"module","title":"Events - Turboprop.Hooks.PinInput","doc":"","ref":"Turboprop.Hooks.PinInput.html#module-events"},{"type":"module","title":"From the client - Turboprop.Hooks.PinInput","doc":"If set, the client will push the following events to the server:\n\n- `data-on-change`: Emitted when any of the inputs change.\n- `data-on-complete`: Emitted when all inputs have been filled.\n- `data-on-invalid`: Emitted when the entire input is invalid.","ref":"Turboprop.Hooks.PinInput.html#module-from-the-client"},{"type":"module","title":"From the server - Turboprop.Hooks.PinInput","doc":"The following events can be sent to the component through `push_event/3`.\n\n- `clear`: Clears the input. Accepts no parameters.","ref":"Turboprop.Hooks.PinInput.html#module-from-the-server"},{"type":"module","title":"Example - Turboprop.Hooks.PinInput","doc":"```elixir\ndef render(assigns) do\n  ~H\"\"\"\n   \n     \n       OTP \n       \n         \n         \n         \n       \n     \n   \n  \"\"\"\nend\n\n@impl true\ndef handle_event(\"submit\", %{\"value\" => value}, socket) do\n  # Do something with value...\n  {:noreply, socket}\n  \nend\n```","ref":"Turboprop.Hooks.PinInput.html#module-example"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input/0","doc":"Wrapper element to initialise the hook.","ref":"Turboprop.Hooks.PinInput.html#pin_input/0"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_input/0","doc":"Input element.\n\nSince the pin input allows one character per input, this element needs to be added multiple times.","ref":"Turboprop.Hooks.PinInput.html#pin_input_input/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.PinInput.pin_input_input/0","doc":"- `data-index`: Increasing index for each input. Needs to be an integer *and* start at `0`.","ref":"Turboprop.Hooks.PinInput.html#pin_input_input/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_label/0","doc":"Label for the input.","ref":"Turboprop.Hooks.PinInput.html#pin_input_label/0"},{"type":"function","title":"Turboprop.Hooks.PinInput.pin_input_root/0","doc":"Wrapper around the input.","ref":"Turboprop.Hooks.PinInput.html#pin_input_root/0"},{"type":"module","title":"Turboprop.Merge","doc":"Provides a set of utilities for efficiently merging and managing class lists in Phoenix applications using Tailwind. Turboprop Merge\nensures that class conflicts are resolved before being applied to the element.\n\nTurboprop Merge intelligently handles class precedence, merges multiple class strings while eliminating redundancies, and utilizes an\ninternal caching mechanism to optimize performance for repeated merge operations. It supports complex scenarios like conditional class\napplication, as well as arbitrary values, properties and modifiers.","ref":"Turboprop.Merge.html"},{"type":"module","title":"Features - Turboprop.Merge","doc":"- **Class Merging**: Merges multiple Tailwind CSS classes into a single optimized class string.\n- **Conflict Resolution**: Prioritises the class name last added to the list.\n- **Caching Mechanism**: Uses an internal cache to speed up the merging process for classes that have been processed before.","ref":"Turboprop.Merge.html#module-features"},{"type":"function","title":"Turboprop.Merge.join/1","doc":"Joins a list of classes.","ref":"Turboprop.Merge.html#join/1"},{"type":"function","title":"Turboprop.Merge.merge/2","doc":"Joins and merges a list of classes.\n\nPasses the input to `join/1` before merging.","ref":"Turboprop.Merge.html#merge/2"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.4 - 2024.06-11 - Changelog","doc":"","ref":"changelog.html#0-1-4-2024-06-11"},{"type":"extras","title":"Added - Changelog","doc":"- New hook: `Turboprop.Hooks.PinInput`","ref":"changelog.html#added"},{"type":"extras","title":"0.1.3 - 2024-06-10 - Changelog","doc":"Initial release.","ref":"changelog.html#0-1-3-2024-06-10"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}